@@ -84,7 +84,7 @@ static R_INLINE SEXP matchnames (SEXP x, SEXP names) {
   PROTECT(index = match(x,names,0)); nprotect++;
   idx = INTEGER(index);
   for (k = 0; k < n; k++) {
-    if (idx[k]==0) error("variable %s not found",CHARACTER_DATA(STRING_ELT(nm,k)));
+    if (idx[k]==0) error("variable '%s' not found",CHARACTER_DATA(STRING_ELT(nm,k)));
     idx[k] -= 1;
   }
   UNPROTECT(nprotect);
